Learn R Programming

Rariant (version 1.8.3)

Rariant-package: Rariant package

Description

The 'Rariant' package offers the framework to identify and characterize shifts of variant frequencies in a comparative setting from high-throughput short-read sequencing data. It estimates shifts in the non-consensus variant frequency and provides confidence estimates that allow for a quantitative assessment of presence or absence of variants. The vignette accompanying the package gives a detailed explanation and outlines a typical workflow on real data.

Arguments

See Also

rariant

vignette(package = "Rariant")

Examples

Run this code
help("rariant")

vignette(package = "Rariant")

Run the code above in your browser using DataLab