## S3 method for class 'BamFile,BamFile,GRanges':
rariant(test, control, region,
beta = 0.95, alpha = 1 - beta, select = TRUE, consensus,
resultFile, strand = c("both", "plus", "minus"), nCycles = 10,
minQual = 20, block = 1e4, value = TRUE, criteria = c("both",
"any", "fet", "ci")) ## S3 method for class 'character,character,GRanges':
rariant(test, control, region,
beta = 0.95, alpha = 1 - beta, select = TRUE, consensus,
resultFile, strand = c("both", "plus", "minus"), nCycles = 10,
minQual = 20, block = 1e4, value = TRUE, criteria = c("both",
"any", "fet", "ci"))
## S3 method for class 'array,array,GRanges':
rariant(test, control, region, beta =
0.95, alpha = 1 - beta, select = TRUE, consensus, strand = c("both",
"plus", "minus"), criteria = c("both", "any", "fet", "ci"))
rariantStandalone()
readRariant(file, ...)
writeRariant(x, file, ...)
The 'select' parameter determines whether only significant variant sites or all sites are returned. While the first is suitable for detecting variants, the second becomes relevant assessing for example the abundance of variants at particular sites of interest - an example would be to determine the absence of a specific variant.
For analyses over large genomic regions and for use with infrastructure outside of R, initiating the calling from the command line may be a desirable alternative. The 'rariantStandalone' functions returns the full path to a script that can be directly called from the command line. For further details, see the help of the script by calling it with the '-h' option, for example 'rariant -h'.
The 'readRariant' and 'writeRariant' functions allow to import and export the results of a 'rariant' call from and to a file output, and will return the same object.
library(GenomicRanges)
control_bam = system.file("extdata", "NRAS.Control.bam", package = "h5vcData", mustWork = TRUE)
test_bam = system.file("extdata", "NRAS.AML.bam", package = "h5vcData", mustWork = TRUE)
roi = GRanges("1", IRanges(start = 115258439, end = 115259089))
vars = rariant(test_bam, control_bam, roi)
vars_all = rariant(test_bam, control_bam, roi, select =
FALSE)
system2(rariantStandalone(), "-h")Run the code above in your browser using DataLab