Learn R Programming

Rariant (version 1.8.3)

rariantInspect: Interactive inspection

Description

Interactively inspect variant sites and results of the 'rariant' function.

Usage

rariantInspect(x)

Arguments

x
The return value of the 'rariant' or 'readRariant' function.

Details

With the web interface of 'rariantInspect' can existing variant calls and assessment be explored interactively. It allows to select the genomic region of interest and the type of event. Results are shown as both a confidence interval plot and a results table that can be further filtered and reordered.

Examples

Run this code
example(rariant)

rariantInspect(vars_all)

Run the code above in your browser using DataLab