Rdocumentation
powered by
Learn R Programming
Rariant (version 1.8.3)
tallyBam: Tally a genomic region
Description
Create the nucleotide count table ('tally') of a genomic region from a BAM file.
Usage
tallyBamRegion(bam, region, minBase = 0, minMap = 0, maxDepth = 10000)
Arguments
bam
BAM file
region
GRanges with the region to tally, with one entry.
minBase, minMap
Minimum base call and mapping quality for reads to be considered for the nucleotide count table [default: 0]. Reads with a lower quality are dropped.
maxDepth
Maximal sequencing depth to analyze.
Value
An integer array with the dimensions:
position
{Length: width(region)}
base
A, C, G, T
strand
+, -
Details
For details, look at the documentation of the underlying 'tallyBAM' function in the 'h5vc' package.
See Also
h5vc::tallyBAM, deepSNV::bam2R, Rsamtools::pileup